@@ -25,9 +25,9 @@
 
 // =================================================================
 // File Name : archimedes.c
-// Version   : release 0.1.0
+// Version   : release 0.1.4
 // Date of Creation : 07 Dec.2003, Paris, France, Jean Michel Sellier
-// Last Revision : 10 September 2007, Siracusa, Italy, Jean Michel Sellier.
+// Last Revision : 15 September 2007, Siracusa, Italy, Jean Michel Sellier.
 // System of Measure : M.K.S.C. System
 // =================================================================
 
@@ -50,7 +50,7 @@
 #define MN3 4
 #define NXM 308
 #define NYM 308
-#define DIME 2003
+#define DIME 1003
 #define ITMAX 10000000
 #define POISSONITMAX 1500
 #define SMALL 1.e-5
@@ -66,12 +66,17 @@
 #define MESHFORMAT 1 // output file in Mesh format
 
 // definition of the material reference table
-#define NOAMTIA 3   // Number Of All Material Taken Into Account (excluding SiO2)
+#define NOAMTIA 8   // Number Of All Material Taken Into Account (excluding SiO2)
 // ********************
 #define iSIO2 -1      // reference number to Silicon Oxide
 #define SILICON 0    // reference number to Silicon
 #define GAAS 1       // reference number to GaAs
 #define GERMANIUM 2  // reference number to Germanium
+#define INSB 3       // reference number to InSb
+#define ALSB 4       // reference number to AlSb
+#define ALXINXSB 5   // reference number to Al_x In_x Sb
+#define ALXIN1XSB 6  // reference number to Al_x In_(1-x) Sb
+#define ALAS 7       // reference number to AlAs
 // ********************
 
 #define NUMSIO2 2 // maximum number of SiO2 interfaces
@@ -114,13 +119,12 @@ real HHM[NOAMTIA+1][3];
 real HM[NOAMTIA+1][3];
 real GM[NOAMTIA+1];
 real SWK[NOAMTIA+1][3][14][DIME+1];
-real P[NPMAX+1][7],EC[3];
+real P[NPMAX+1][7];
 real KX,KY,KZ,X,Y;
 real TS,EPP,DDmax;
 real EDGE[4][NXM+NYM+1][4];
 real CIMP,QD2,TAUW;
 real EPSRSIO2;
-real DG[NXM+1][NYM+1],DL[NXM+1][NYM+1];
 real bufx2d[NXM+1][NYM+1];
 real bufy2d[NXM+1][NYM+1];
 real ux2d[NXM+1][NYM+1][MN3+1];
@@ -148,6 +152,7 @@ real RHO[NOAMTIA+1];
 real DA[NOAMTIA+1];
 real UL[NOAMTIA+1];
 real EMIN[NOAMTIA+1][4];
+real XVAL[NOAMTIA+1];
 
 // All structures here...
 time_t binarytime;
@@ -193,7 +198,7 @@ main(int argc,char* argv[])
       if (optind < argc)
         printf("Too many arguments\n");
         printf("Try `%s --help' for more information.\n",progname);
-      exit (1);
+      exit(1);
     }
 
   /* `help' should come first.  If `help' is requested, ignore the other
@@ -232,7 +237,7 @@ Report bugs to sellier@dmi.unict.it or archimedes@southnovel.eu\n");
   if (v)
     {
       /* Print version number.  */
-      printf("archimedes - GNU archimedes 0.1.0\n");
+      printf("archimedes - GNU archimedes 0.1.4\n");
       /* xgettext: no-wrap */
       printf("\n");
       printf("\
@@ -265,14 +270,25 @@ For more information about these matters, see the file named COPYING.\n",
      NOVALLEY[SILICON]=1;
      NOVALLEY[GERMANIUM]=1;
      NOVALLEY[GAAS]=2;
+     NOVALLEY[INSB]=2;
+     NOVALLEY[ALSB]=2;
+     NOVALLEY[ALXINXSB]=2;
+     NOVALLEY[ALXIN1XSB]=2;
+     NOVALLEY[ALAS]=2;
 // Dielectric constant for Silicon Oxide SiO2
      EPSRSIO2=17.0*EPS0;
 // Dielectric constant for Semiconducting materials
      EPSR[SILICON]=11.7*EPS0;
      EPSR[GERMANIUM]=16.2*EPS0;
      EPSR[GAAS]=12.90*EPS0;
-// GaAs high frequency dieletric constant
+     EPSR[INSB]=17.65*EPS0;
+     EPSR[ALSB]=12.04*EPS0;
+     EPSR[ALAS]=10.06;
+// III-V semiconductor compounds high frequency dieletric constant
      EPF[GAAS]=10.92;
+     EPF[INSB]=15.68;
+     EPF[ALSB]=9.88;
+     EPF[ALAS]=8.16;
      int ii;
      for(ii=0;ii<NOAMTIA;ii++){
        int i;
@@ -291,8 +307,11 @@ For more information about these matters, see the file named COPYING.\n",
      HWO[SILICON][5]=0.0590;
 // Germanium optical phonon scattering energy (eV)
      HWO[GERMANIUM][0]=0.09;
-// GaAs optical phonon scattering energy (eV)
+// III-V semiconductor compounds optical phonon scattering energy (eV)
      HWO[GAAS][0]=0.03536;
+     HWO[INSB][0]=0.0282;
+     HWO[ALSB][0]=0.0360;
+     HWO[ALAS][0]=0.05009;
 // Silicon optical coupling constants (eV/m)
      DTK[SILICON][0]=0.05e11;
      DTK[SILICON][1]=0.08e11;
@@ -302,8 +321,11 @@ For more information about these matters, see the file named COPYING.\n",
      DTK[SILICON][5]=0.20e11;
 // Germanium optical coupling constants (eV/m)
      DTK[GERMANIUM][0]=1.889e11;
-// GaAs optical coupling constant (eV/m)
+// III-V semiconductor compounds optical coupling constant (eV/m)
      DTK[GAAS][0]=1.11e11;
+     DTK[INSB][0]=0.47e11;
+     DTK[ALSB][0]=0.55e11;
+     DTK[ALAS][0]=3.0e11;
 // Silicon optical phonon Z-factor
      ZF[SILICON][0]=1.;
      ZF[SILICON][1]=1.;
@@ -313,58 +335,67 @@ For more information about these matters, see the file named COPYING.\n",
      ZF[SILICON][5]=4.;
 // Germanium optical phonon Z-factor
      ZF[GERMANIUM][0]=1.;
-// GaAs optical phonon Z-factor
+// III-V semiconductor compounds optical phonon Z-factor
      ZF[GAAS][0]=1.;
+     ZF[INSB][0]=1.;
+     ZF[ALSB][0]=1.;
+     ZF[ALAS][0]=1.;
 // Silicon Crystal Density (Kg/m^3)
      RHO[SILICON]=2330.;
 // Germanium Crystal Density (Kg/m^3)
      RHO[GERMANIUM]=5320.;
-// GaAs Crystal Density (Kg/m^3)
+// III-V semiconductor compounds Crystal Density (Kg/m^3)
      RHO[GAAS]=5360.;
+     RHO[INSB]=5790.;
+     RHO[ALSB]=4288.;
+     RHO[ALAS]=5650.;
 // Silicon acoustic deformation potential (Joule)
      DA[SILICON]=9.*1.60217733e-19;
 // Germanium acoustic deformation potential (Joule)
      DA[GERMANIUM]=9.*1.60217733e-19;
-// GaAs acoustic deformation potential (Joule)
+// III-V semiconductor compounds acoustic deformation potential (Joule)
      DA[GAAS]=7.*1.60217733e-19;
+     DA[INSB]=5.96*1.60217733e-19;
+     DA[ALSB]=4.6*1.60217733e-19;
+     DA[ALAS]=9.3*1.60217733e-19;
 // Silicon longitudinal sound velocity (m/sec)
      UL[SILICON]=9040.;
 // Germanium longitudinal sound velocity (m/sec)
      UL[GERMANIUM]=5400.;
-// GaAs longitudinal sound velocity (m/sec)
+// III-V semiconductor compounds longitudinal sound velocity (m/sec)
      UL[GAAS]=5240.;
-// Semiconductor materials energy gap
-     EG[SILICON]=1.21-3.333e-4*TL;
-     printf("EG[SILICON]      = %g\n",EG[SILICON]);
-     EG[GERMANIUM]=0.747-3.587e-4*TL;
-     printf("EG[GERMANIUM]    = %g\n",EG[GERMANIUM]);
-     EG[GAAS]=1.54-4.036e-4*TL;//0.32;???
-     printf("EG[GAAS]         = %g\n",EG[GAAS]);
-     printf("\n");
+     UL[INSB]=4060.;
+     UL[ALSB]=4600.;
+     UL[ALAS]=5650.;
 // Silicon minimum energy
      EMIN[SILICON][1]=0.0;
 // Germanium minimum energy
      EMIN[GERMANIUM][1]=0.173;
-// GaAs minimum energy of GAMMA-valley
+// III-V semiconductor compounds minimum energy of GAMMA-valley
      EMIN[GAAS][1]=0.0;
-// GaAs minimum energy of L-valley (eV)
+     EMIN[INSB][1]=0.0;
+     EMIN[ALSB][1]=0.507;
+     EMIN[ALAS][1]=0.767;
+// III-V semiconductor compounds minimum energy of L-valley (eV)
      EMIN[GAAS][2]=0.323;
+     EMIN[INSB][2]=1.038;
+     EMIN[ALSB][2]=0.292;
+     EMIN[ALAS][2]=0.332;
 // Definition of effective mass for all materials in all valleys
      MSTAR[SILICON][1]=0.32;
      MSTAR[GAAS][1]=0.067; // Gamma-valley
      MSTAR[GAAS][2]=0.350; // L-valley
      MSTAR[GERMANIUM][1]=0.22;
+     MSTAR[INSB][1]=0.013;
+     MSTAR[INSB][2]=0.442;
+     MSTAR[ALSB][1]=0.14;
+     MSTAR[ALSB][2]=0.442;
+     MSTAR[ALAS][1]=0.149;
+     MSTAR[ALAS][2]=pow(1.456*pow(0.165,2.),1./3.);
 // non-parabolicity coefficient for Silicon
      alphaK[SILICON][1]=0.5;
 // non-parabolicity coefficient for Germanium
      alphaK[GERMANIUM][1]=0.65;
-// non-parabolicity coefficient for GaAs in the GAMMA-valley
-     alphaK[GAAS][1]=pow(1.-MSTAR[GAAS][1],2.)/EG[GAAS];//0.611;
-     printf("alphaK_gamma[GaAs] = %g\n",alphaK[GAAS][1]);
-// non-parabolicity coefficient for GaAs in the L-valley
-     alphaK[GAAS][2]=pow(1.-MSTAR[GAAS][2],2.)/EG[GAAS];//0.242;
-     printf("alphaK_L[GaAs]     = %g\n",alphaK[GAAS][2]);
-     printf("\n");
 // ======================================================
 // ======================================================
 
@@ -379,6 +410,96 @@ For more information about these matters, see the file named COPYING.\n",
 // ===========================================================
      Read_Input_File();
 
+// III-V Semiconductor materials energy gap (depending on the lattice temperature)
+     printf("\n");
+     EG[SILICON]=1.21-3.333e-4*TL;
+     printf("EG[SILICON]      = %g\n",EG[SILICON]);
+     EG[GERMANIUM]=0.747-3.587e-4*TL;
+     printf("EG[GERMANIUM]    = %g\n",EG[GERMANIUM]);
+     EG[GAAS]=1.54-4.036e-4*TL;
+     printf("EG[GAAS]         = %g\n",EG[GAAS]);
+     EG[INSB]=0.2446-2.153e-4*TL;
+     printf("EG[INSB]         = %g\n",EG[INSB]);
+     EG[ALSB]=1.696-2.20e-4*TL;
+     printf("EG[ALSB]         = %g\n",EG[ALSB]);
+     EG[ALAS]=2.314-3.0e-4*TL;
+     printf("EG[ALAS]         = %g\n",EG[ALAS]);
+     printf("\n");
+// all the following non-parabolicity coefficients depend on lattice temperature
+// non-parabolicity coefficient for GaAs in the GAMMA-valley
+     alphaK[GAAS][1]=pow(1.-MSTAR[GAAS][1],2.)/(EG[GAAS]+EMIN[GAAS][1]);//expected value = 0.611
+     printf("alphaK_gamma[GaAs] = %g\n",alphaK[GAAS][1]);
+// non-parabolicity coefficient for GaAs in the L-valley
+     alphaK[GAAS][2]=pow(1.-MSTAR[GAAS][2],2.)/(EG[GAAS]+EMIN[GAAS][2]);//expected value = 0.242;
+     printf("alphaK_L[GaAs]     = %g\n",alphaK[GAAS][2]);
+// non-parabolicity coefficient for InSb in the GAMMA-valley
+     alphaK[INSB][1]=pow(1.-MSTAR[INSB][1],2.)/(EG[INSB]+EMIN[INSB][1]);//5.59;
+     printf("alphaK_gamma[InSb] = %g\n",alphaK[INSB][1]);
+// non-parabolicity coefficient for InSb in the L-valley
+     alphaK[INSB][2]=pow(1.-MSTAR[INSB][2],2.)/(EG[INSB]+EMIN[INSB][2]);//1.789;
+     printf("alphaK_L[InSb]     = %g\n",alphaK[INSB][2]);
+// non-parabolicity coefficient for AlSb in the GAMMA-valley
+     alphaK[ALSB][1]=pow(1.-MSTAR[ALSB][1],2.)/(EG[ALSB]+EMIN[ALSB][1]);//0.321;
+     printf("alphaK_gamma[AlSb] = %g\n",alphaK[ALSB][1]);
+// non-parabolicity coefficient for AlSb in the L-valley
+     alphaK[ALSB][2]=pow(1.-MSTAR[ALSB][2],2.)/(EG[ALSB]+EMIN[ALSB][2]);//0.135;
+     printf("alphaK_L[AlSb]     = %g\n",alphaK[ALSB][2]);
+// non-parabolicity coefficient for AlAs in the GAMMA-valley
+     alphaK[ALAS][1]=pow(1.-MSTAR[ALAS][1],2.)/(EG[ALAS]+EMIN[ALAS][1]);//0.321;
+     printf("alphaK_gamma[AlAs] = %g\n",alphaK[ALAS][1]);
+// non-parabolicity coefficient for AlAs in the L-valley
+     alphaK[ALAS][2]=pow(1.-MSTAR[ALAS][2],2.)/(EG[ALAS]+EMIN[ALAS][2]);//0.135;
+     printf("alphaK_L[AlAs]     = %g\n",alphaK[ALAS][2]);
+
+// Semiconductor compounds
+// ***
+// Relative dielectric constant for semiconductor compounds
+     EPSR[ALXINXSB]=XVAL[ALXINXSB]*EPSR[ALSB]+XVAL[ALXINXSB]*EPSR[INSB];
+     EPSR[ALXIN1XSB]=XVAL[ALXIN1XSB]*EPSR[ALSB]+(1.-XVAL[ALXIN1XSB])*EPSR[INSB];
+// semiconductor compounds high frequency dieletric constant
+     EPF[ALXINXSB]=XVAL[ALXINXSB]*(EPF[ALSB]+EPF[INSB]);
+     EPF[ALXIN1XSB]=XVAL[ALXIN1XSB]*EPF[ALSB]+(1.-XVAL[ALXIN1XSB])*EPF[INSB];
+// semiconductor compounds optical phonon scattering energy (eV)
+     HWO[ALXINXSB][0]=XVAL[ALXINXSB]*(HWO[ALSB][0]+HWO[INSB][0]);
+     HWO[ALXIN1XSB][0]=XVAL[ALXIN1XSB]*HWO[ALSB][0]+(1.-XVAL[ALXIN1XSB])*HWO[INSB][0];
+// semiconductor compounds optical coupling constants (eV/m)
+     DTK[ALXINXSB][0]=XVAL[ALXINXSB]*(DTK[ALSB][0]+DTK[INSB][0]);
+     DTK[ALXIN1XSB][0]=XVAL[ALXIN1XSB]*DTK[ALSB][0]+(1.-XVAL[ALXIN1XSB])*DTK[INSB][0];
+// semiconductor compounds optical phonon Z-factor
+     ZF[ALXINXSB][0]=XVAL[ALXINXSB]*(ZF[ALSB][0]+ZF[INSB][0]);
+     ZF[ALXIN1XSB][0]=XVAL[ALXIN1XSB]*ZF[ALSB][0]+(1.-XVAL[ALXIN1XSB])*ZF[INSB][0];
+// semiconductor compounds Crystal Density (Kg/m^3)
+     RHO[ALXINXSB]=XVAL[ALXINXSB]*(RHO[ALSB]+RHO[INSB]);
+     RHO[ALXIN1XSB]=XVAL[ALXIN1XSB]*RHO[ALSB]+(1.-XVAL[ALXIN1XSB])*RHO[INSB];
+// semiconductor compounds acoustic deformation potential (Joule)
+     DA[ALXINXSB]=XVAL[ALXINXSB]*(DA[ALSB]+DA[INSB]);
+     DA[ALXIN1XSB]=XVAL[ALXIN1XSB]*DA[ALSB]+(1.-XVAL[ALXIN1XSB])*DA[INSB];
+// semiconductor compounds longitudinal sound velocity (m/sec)
+     UL[ALXINXSB]=XVAL[ALXINXSB]*(UL[ALSB]+UL[INSB]);
+     UL[ALXIN1XSB]=XVAL[ALXIN1XSB]*UL[ALSB]+(1.-XVAL[ALXIN1XSB])*UL[INSB];
+// semiconductor compounds energy gap
+     EG[ALXINXSB]=XVAL[ALXINXSB]*(EG[ALSB]+EG[INSB]);
+     EG[ALXIN1XSB]=XVAL[ALXIN1XSB]*EG[ALSB]+(1.-XVAL[ALXIN1XSB])*EG[INSB];
+// semiconductor compounds energy minimum of GAMMA-valley
+     EMIN[ALXINXSB][1]=XVAL[ALXINXSB]*(EMIN[ALSB][1]+EMIN[INSB][1]);
+     EMIN[ALXIN1XSB][1]=XVAL[ALXIN1XSB]*EMIN[ALSB][1]+(1.-XVAL[ALXIN1XSB])*EMIN[INSB][1];
+// semiconductor compounds energy minimum 0f L-valley
+     EMIN[ALXINXSB][2]=XVAL[ALXINXSB]*(EMIN[ALSB][2]+EMIN[INSB][2]);
+     EMIN[ALXIN1XSB][2]=XVAL[ALXIN1XSB]*EMIN[ALSB][2]+(1.-XVAL[ALXIN1XSB])*EMIN[INSB][2];
+// GAMMA-valley effective mass
+     MSTAR[ALXINXSB][1]=XVAL[ALXINXSB]*(MSTAR[ALSB][1]+MSTAR[INSB][1]);
+     MSTAR[ALXIN1XSB][1]=XVAL[ALXIN1XSB]*MSTAR[ALSB][1]+(1.-XVAL[ALXIN1XSB])*MSTAR[INSB][1];
+// L-valley effective mass
+     MSTAR[ALXINXSB][2]=XVAL[ALXINXSB]*(MSTAR[ALSB][2]+MSTAR[INSB][2]);
+     MSTAR[ALXIN1XSB][2]=XVAL[ALXIN1XSB]*MSTAR[ALSB][2]+(1.-XVAL[ALXIN1XSB])*MSTAR[INSB][2];
+// non-parabolicity coefficient for semiconductor compounds in the GAMMA-valley
+     alphaK[ALXINXSB][1]=XVAL[ALXINXSB]*(alphaK[ALSB][1]+alphaK[INSB][1]);
+     alphaK[ALXIN1XSB][1]=XVAL[ALXIN1XSB]*alphaK[ALSB][1]+(1.-XVAL[ALXIN1XSB])*alphaK[INSB][1];
+// non-parabolicity coefficient for Al_x In_(1-x) Sb in the L-valley
+     alphaK[ALXINXSB][2]=XVAL[ALXINXSB]*(alphaK[ALSB][2]+alphaK[INSB][2]);
+     alphaK[ALXIN1XSB][2]=XVAL[ALXIN1XSB]*alphaK[ALSB][2]+(1.-XVAL[ALXIN1XSB])*alphaK[INSB][2];
+// ***
+
 // Closure of the input file
 // =========================
      fclose(fp);
@@ -404,8 +525,10 @@ For more information about these matters, see the file named COPYING.\n",
      if(Model_Number==MCE || Model_Number==MCEH){
       int i;
       for(i=0;i<NOAMTIA;i++) MCparameters(i);
+      printf("\n");
       MCdevice_config();
      }
+     printf("/n");
 // HERE IS THE SIMULATION
 // ======================
      for(c=1;c<=ITMAX;c++) updating(Model_Number);
